@@ -21,7 +21,7 @@
 #   This specific module is licensed under the Perl Artistic License.
 #
 #
-#   $Id: Dict.pm,v 1.8 2004/12/16 00:30:52 fredo Exp $
+#   $Id: Dict.pm,v 2.0 2005/11/16 02:16:00 areibens Exp $
 #
 #=======================================================================
 package PDF::API2::Basic::PDF::Dict;
@@ -102,11 +102,17 @@ sub outobjdeep
 
     if (defined $self->{' stream'} or defined $self->{' streamfile'} or defined $self->{' streamloc'})
     {
-        if ($self->{'Filter'} || !defined $self->{' stream'})
+        if($self->{'Filter'} && $self->{' nofilt'})
+        {
+            $self->{Length}||= PDF::API2::Basic::PDF::Number->new(length($self->{' stream'}));
+        }
+        elsif($self->{'Filter'} || !defined $self->{' stream'})
         {
             $self->{'Length'} = PDF::API2::Basic::PDF::Number->new(0) unless (defined $self->{'Length'});
             $pdf->new_obj($self->{'Length'}) unless ($self->{'Length'}->is_obj($pdf));
-        } else {
+        } 
+        else 
+        {
             $self->{'Length'} = PDF::API2::Basic::PDF::Number->new(length($self->{' stream'}));
             ## $self->{'Length'} = PDF::API2::Basic::PDF::Number->new(length($self->{' stream'}) + 1);
             ## this old code seams to burp acro6, lets see what breaks next -- fredo
@@ -208,17 +214,16 @@ sub outobjdeep
             $fh->print($str);
         }
         ## $fh->print("\n"); # newline goes into endstream
-
     }
 
     if (defined $self->{' stream'} or defined $self->{' streamfile'})
     {
-       $len = $fh->tell - $loc;
-       if ($self->{'Length'}{'val'} != $len)
-       {
-           $self->{'Length'}{'val'} = $len;
-           $pdf->out_obj($self->{'Length'}) if ($self->{'Length'}->is_obj($pdf));
-       }
+        $len = $fh->tell - $loc;
+        if ($self->{'Length'}{'val'} != $len)
+        {
+            $self->{'Length'}{'val'} = $len;
+            $pdf->out_obj($self->{'Length'}) if ($self->{'Length'}->is_obj($pdf));
+        }
 
         $fh->print("\nendstream"); # next is endobj which has the final cr
     }
