@@ -8,7 +8,7 @@
 #   A Perl Module Chain to faciliate the Creation and Modification
 #   of High-Quality "Portable Document Format (PDF)" Files.
 #
-#   Copyright 1999-2004 Alfred Reibenschuh <areibens@cpan.org>.
+#   Copyright 1999-2005 Alfred Reibenschuh <areibens@cpan.org>.
 #
 #=======================================================================
 #
@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: Lite.pm,v 1.9 2005/02/28 18:00:06 fredo Exp $
+#   $Id: Lite.pm,v 2.1 2007/05/08 18:32:09 areibens Exp $
 #
 #=======================================================================
 
@@ -43,7 +43,7 @@ BEGIN {
 
     use vars qw( $VERSION $hasWeakRef );
 
-    ( $VERSION ) = '$Revision: 1.9 $' =~ /Revision: (\S+)\s/; # $Date: 2005/02/28 18:00:06 $
+    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 2.1 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2007/05/08 18:32:09 $
 
 }
 
@@ -94,7 +94,7 @@ sub page {
     $self->{page}=$self->{api}->page;
     $self->{page}->mediabox(@_) if($_[0]);
     $self->{gfx}=$self->{page}->gfx;
-#   $self->{gfx}->compress;
+#   $self->{gfx}->compressFlate;
     return $self;
 }
 
@@ -670,6 +670,27 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: Lite.pm,v $
+    Revision 2.1  2007/05/08 18:32:09  areibens
+    renamed compress to compressFlate
+
+    Revision 2.0  2005/11/16 02:16:00  areibens
+    revision workaround for SF cvs import not to screw up CPAN
+
+    Revision 1.2  2005/11/16 01:27:48  areibens
+    genesis2
+
+    Revision 1.1  2005/11/16 01:19:24  areibens
+    genesis
+
+    Revision 1.12  2005/06/17 19:43:47  fredo
+    fixed CPAN modulefile versioning (again)
+
+    Revision 1.11  2005/06/17 18:53:33  fredo
+    fixed CPAN modulefile versioning (dislikes cvs)
+
+    Revision 1.10  2005/03/14 22:01:05  fredo
+    upd 2005
+
     Revision 1.9  2005/02/28 18:00:06  fredo
     removed color method since businesscolor is not available anymore in PDF::API2
 
