@@ -8,7 +8,7 @@
 #   A Perl Module Chain to faciliate the Creation and Modification
 #   of High-Quality "Portable Document Format (PDF)" Files.
 #
-#   Copyright 1999-2004 Alfred Reibenschuh <areibens@cpan.org>.
+#   Copyright 1999-2005 Alfred Reibenschuh <areibens@cpan.org>.
 #
 #=======================================================================
 #
@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: kozgopromediumacro.pm,v 1.7 2004/11/22 02:03:40 fredo Exp $
+#   $Id: kozgopromediumacro.pm,v 2.0 2005/11/16 02:16:04 areibens Exp $
 #
 #=======================================================================
 
@@ -696,6 +696,18 @@ __END__
 =head1 HISTORY
 
     $Log: kozgopromediumacro.pm,v $
+    Revision 2.0  2005/11/16 02:16:04  areibens
+    revision workaround for SF cvs import not to screw up CPAN
+
+    Revision 1.2  2005/11/16 01:27:48  areibens
+    genesis2
+
+    Revision 1.1  2005/11/16 01:19:25  areibens
+    genesis
+
+    Revision 1.8  2005/03/14 22:01:09  fredo
+    upd 2005
+
     Revision 1.7  2004/11/22 02:03:40  fredo
     deleted obsolete character widths
 
