@@ -27,11 +27,12 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: verdana.pm,v 1.7 2005/06/07 23:21:40 fredo Exp $
+#   $Id: verdana.pm,v 2.0 2005/11/16 02:18:15 areibens Exp $
 #
 #=======================================================================
+package PDF::API2::Resource::Font::CoreFont::verdana;
 
-$fonts->{verdana}= {
+$FONTDATA = {
     'fontname' => 'Verdana',
     'type' => 'TrueType',
     'apiname' => 'Verd',
@@ -876,6 +877,18 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: verdana.pm,v $
+    Revision 2.0  2005/11/16 02:18:15  areibens
+    revision workaround for SF cvs import not to screw up CPAN
+
+    Revision 1.2  2005/11/16 01:27:50  areibens
+    genesis2
+
+    Revision 1.1  2005/11/16 01:19:27  areibens
+    genesis
+
+    Revision 1.8  2005/09/12 16:56:22  fredo
+    applied mod_perl patch by Paul Schilling <pfschill@sbcglobal.net>
+
     Revision 1.7  2005/06/07 23:21:40  fredo
     fontkey correction
 
