@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: GIF.pm,v 1.11 2005/06/17 19:44:04 fredo Exp $
+#   $Id: GIF.pm,v 2.0 2005/11/16 02:18:23 areibens Exp $
 #
 #=======================================================================
 
@@ -44,7 +44,7 @@ BEGIN {
     use vars qw(@ISA $VERSION);
     @ISA = qw( PDF::API2::Resource::XObject::Image );
 
-    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 1.11 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2005/06/17 19:44:04 $
+    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 2.0 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2005/11/16 02:18:23 $
 
 }
 no warnings qw[ deprecated recursion uninitialized ];
@@ -287,6 +287,15 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: GIF.pm,v $
+    Revision 2.0  2005/11/16 02:18:23  areibens
+    revision workaround for SF cvs import not to screw up CPAN
+
+    Revision 1.2  2005/11/16 01:27:50  areibens
+    genesis2
+
+    Revision 1.1  2005/11/16 01:19:27  areibens
+    genesis
+
     Revision 1.11  2005/06/17 19:44:04  fredo
     fixed CPAN modulefile versioning (again)
 
