@@ -8,7 +8,7 @@
 #   A Perl Module Chain to faciliate the Creation and Modification
 #   of High-Quality "Portable Document Format (PDF)" Files.
 #
-#   Copyright 1999-2004 Alfred Reibenschuh <areibens@cpan.org>.
+#   Copyright 1999-2005 Alfred Reibenschuh <areibens@cpan.org>.
 #
 #=======================================================================
 #
@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: PNM.pm,v 1.7 2004/12/16 00:30:55 fredo Exp $
+#   $Id: PNM.pm,v 2.1 2007/05/24 19:29:46 areibens Exp $
 #
 #=======================================================================
 package PDF::API2::Resource::XObject::Image::PNM;
@@ -42,7 +42,7 @@ BEGIN {
 
     use vars qw(@ISA $VERSION);
     @ISA = qw( PDF::API2::Resource::XObject::Image );
-    ( $VERSION ) = '$Revision: 1.7 $' =~ /Revision: (\S+)\s/; # $Date: 2004/12/16 00:30:55 $
+    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 2.1 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2007/05/24 19:29:46 $
 }
 no warnings qw[ deprecated recursion uninitialized ];
 
@@ -174,6 +174,7 @@ sub read_pnm {
         $bpc=1;
         read(INF,$self->{' stream'},($info->{width}*$info->{height}/8));
         $cs='DeviceGray';
+        $self->{Decode}=PDFArray(PDFNum(1),PDFNum(0));
     } elsif($info->{type} == 5) {
         $buf.=<INF>;
         if($info->{max}==255){
@@ -237,6 +238,27 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: PNM.pm,v $
+    Revision 2.1  2007/05/24 19:29:46  areibens
+    fixed pnm bitmap decoding
+
+    Revision 2.0  2005/11/16 02:18:23  areibens
+    revision workaround for SF cvs import not to screw up CPAN
+
+    Revision 1.2  2005/11/16 01:27:50  areibens
+    genesis2
+
+    Revision 1.1  2005/11/16 01:19:27  areibens
+    genesis
+
+    Revision 1.10  2005/06/17 19:44:04  fredo
+    fixed CPAN modulefile versioning (again)
+
+    Revision 1.9  2005/06/17 18:53:35  fredo
+    fixed CPAN modulefile versioning (dislikes cvs)
+
+    Revision 1.8  2005/03/14 22:01:31  fredo
+    upd 2005
+
     Revision 1.7  2004/12/16 00:30:55  fredo
     added no warn for recursion
 
